config Package
==============

:mod:`leapsettings` Module
--------------------------

.. automodule:: leap.config.leapsettings
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`provider_spec` Module
---------------------------

.. automodule:: leap.config.provider_spec
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`providerconfig` Module
----------------------------

.. automodule:: leap.config.providerconfig
    :members:
    :undoc-members:
    :show-inheritance:

